@@ -12,5 +12,5 @@
 format_condition <- function(condition) {
     .must_be_character_vector(condition, null = TRUE)
 
-    paste0("{", paste0(condition, collapse = ","), "}")
+    paste0("{", paste0(sort(condition), collapse = ","), "}")
 }
