@@ -695,3 +695,44 @@ test_that("min_focus_support & filter_empty_foci", {
 
     expect_equal(unlist(res), c(" = 0.7, 0.6", "1 = 0.5", "2 = 0.5"))
 })
+
+
+test_that("errors", {
+    f <- function(condition) { list() }
+    d <- data.frame(n = 1:5 / 5, l = TRUE, i = 1:5, s = letters[1:5])
+
+    expect_error(dig(list(), f), "must be a matrix or a data frame")
+    expect_error(dig(matrix(0, nrow = 5, ncol = 0), f), "must have at least one column")
+    expect_error(dig(matrix(0, nrow = 0, ncol = 5), f), "must have at least one row")
+
+    expect_true(is.list(dig(d, f, condition = c(n, l))))
+    expect_error(dig(d, f, condition = c(n, l, i)),
+                 "columns selected by `condition` must be logical or numeric")
+    expect_error(dig(d, f, condition = c(n, l, s)),
+                 "columns selected by `condition` must be logical or numeric")
+
+    expect_true(is.list(dig(d, f, condition = c(n, l), focus = c(n, l))))
+    expect_error(dig(d, f, condition = c(n, l), focus = c(n, l, i)),
+                 "columns selected by `focus` must be logical or numeric")
+    expect_error(dig(d, f, condition = c(n, l), focus = c(n, l, s)),
+                 "columns selected by `focus` must be logical or numeric")
+})
+
+
+test_that("bug on mixed logical and numeric chains", {
+    fuzzyCO2 <- CO2 |>
+        partition(Plant:Treatment) |>
+        partition(conc, .method = "triangle", .breaks = c(-Inf, 175, 350, 675, Inf)) |>
+        partition(uptake, .method = "triangle", .breaks = c(-Inf, 18, 28, 37, Inf))
+
+    disj <- sub("=.*", "", colnames(fuzzyCO2))
+
+    result <- dig_implications(fuzzyCO2,
+                               antecedent = !starts_with("Treatment"),
+                               consequent = starts_with("Treatment"),
+                               disjoint = disj,
+                               min_support = 0.02,
+                               min_confidence = 0.8)
+
+    expect_true(is_tibble(result))
+})
